@@ -270,6 +270,7 @@ def space(
     disable_controller_mab_weight: Optional[bool] = typer.Option(
         False, help="disable loss weighting in Distance Controller"
     ),
+    n_controllers: Optional[int] = typer.Option(500, help="set the number of controllers for movado (voters)")
 ):
     """
     RTL design space exploration
@@ -321,6 +322,7 @@ def space(
         controller=controller_model,
         estimator=estimation_model,
         controller_mab_weight=not disable_controller_mab_weight,
+        voters=50
     )
 
     execution_time = optimize(
